
Project documentation
=====================
Contents:

.. contents:: Table of Contents

.. toctree::
   :maxdepth: 20

   readme
   quick_start
   recipes
   creating_images
   creating_pdf
   creating_docx
   creating_odt
   cli
   methodology
   talks/pygrunn_2023
   security
   code_of_conduct
   contributor_guidelines
   changelog
   package
